#!/bin/sh

# -- Skript zum Sichern der Daten vom Gambas-Buch, der privaten Daten sowie ausgewählter Ordner.
# -- ACHTUNG: Unbedingt 'Anwendung im Terminal' eintragen, wenn der Starter auf dem Desktop angelegt wird!
#
# Syntax-Muster:
# sudo rsync -av --progress --exclude=.* --exclude=zumLINUX $HOME/GB-Projekte-Buch/ /media/$USER/$STICKNAME/Buch
#
# -- Definition von Farbwerten:
#---------------------------------------------------------
RO="\033[31m"                 # -- rot
FR="\033[1m\033[31m"          # -- rot & fett
FG="\033[1m\033[42m\033[37m"  # -- weiß & fett + grüner HG
NO="\033[0m"                  # -- Farbe normal
#
# -- Definition von Variablen:
#-------------------------------------------------------------------------------------------------
STICKNAME="S_USB_64"                  # -- Name des USB-Sticks, auf den die Daten gesichert werden
MUSIKDATEIORDNER="$HOME/BACKUP_SH"    # -- Pfad zur Ton-Datei
#
df -k | grep /media/$USER/$STICKNAME 1>/dev/null 2>/dev/null
if [ $? -gt 0 ];
then
  echo "${RO}Der USB-Stick:${NO} $STICKNAME ${FR}muss${NO} ${RO}eingehängt sein!";
  echo "Das Sicherungsprogramm wird deshalb beendet!${NO}";
  echo
  echo "Ende mit ENTER!";
  paplay $MUSIKDATEIORDNER/error.ogg
  read a
  exit 0;
else
#
# ------------------------------------------------------------------------------------------------------------
#
# -- BACKUP_SH            Sammlung von Bash-Skripten zur Sicherung mit RSYNC ∑
# -- CLAMAV               Konfiguration der Software 'ClamAV'
# -- CONVERT              Programm zum Hochladen von übersetzten Buchseiten
# -- CRYPT                Anleitung zum Verschlüsseln von (USB-)Laufwerken
# -- Dokumente            Sammlung von Dokumenten
# -- DW                   DokuWiki-Quelldateien
# -- DW_BACKUP            Sammlung
# -- FileZilla3           FTP-Programm zur Administration der Buchseiten auf dem Server
# -- GB3BUCH              Buch-Kapitel und Projekte
# -- public_html          'DocumentRoot' für den lokalen Webserver Lighhttpd (-> Gambas-Buch) und diverse WebPages
# -- Schreibtisch         Sicherung des Inhalts des *aktuellen* Schreibtisches
# -- Umzug                Installation und Konfiguration von System, Desktop und Programmen
# -- ZumPrivaten          Sicherung von *nicht* sicherheitsreleveanten Inhalten
# -- Linux                Sicherung von *nicht* sicherheitsreleveanten Inhalten
#
# ------------------------------------------------------------------------------------------------------------
#
echo
echo "${FG}Sicherung der Daten auf den USB-Stick $STICKNAME mit ENTER starten ...${NO}"
echo "__________________________________________________________________________";
echo
read a

echo
rm -i /media/$USER/$STICKNAME/datum_*
echo
echo

#
if [ -d $HOME/BACKUP_SH ]
then
  sudo rsync -av --delete --progress $HOME/BACKUP_SH /media/$USER/$STICKNAME
fi
#
if [ -d $HOME/CLAMAV ]
then
  sudo rsync -av --delete --progress $HOME/CLAMAV /media/$USER/$STICKNAME
fi
#
if [ -d $HOME/CONVERT ]
then
  sudo rsync -av --delete --progress $HOME/CONVERT /media/$USER/$STICKNAME
fi
#
if [ -d $HOME/CRYPT ]
then
  sudo rsync -av --delete --progress $HOME/CRYPT /media/$USER/$STICKNAME
fi
#
if [ -d $HOME/Dokumente ]
then
  sudo rsync -av --delete --progress $HOME/Dokumente /media/$USER/$STICKNAME
fi
#
if [ -d $HOME/DW ]
then
  sudo rsync -av --delete --progress $HOME/DW /media/$USER/$STICKNAME
fi
#
if [ -d $HOME/DW_BACKUP ]
then
  sudo rsync -av --delete --progress $HOME/DW_BACKUP /media/$USER/$STICKNAME
fi
#
if [ -d $HOME/FileZilla3 ]
then
  sudo rsync -av --delete --progress $HOME/FileZilla3 /media/$USER/$STICKNAME
fi
#
if [ -d $HOME/GB3BUCH ]
then
  sudo rsync -av --delete --progress $HOME/GB3BUCH /media/$USER/$STICKNAME
fi
#
if [ -d $HOME/public_html ]
then
  sudo rsync -av --delete --progress $HOME/public_html /media/$USER/$STICKNAME
fi
#
if [ -d $HOME/Schreibtisch ]
then
  sudo rsync -av --delete --progress $HOME/Schreibtisch /media/$USER/$STICKNAME
fi
#
if [ -d $HOME/UMZUG ]
then
  sudo rsync -av --delete --progress $HOME/UMZUG /media/$USER/$STICKNAME
fi
#
if [ -d $HOME/ZumPrivaten ]
then
  sudo rsync -av --delete --progress $HOME/ZumPrivaten /media/$USER/$STICKNAME
fi
#
if [ -d $HOME/LINUX ]
then
  sudo rsync -av --delete --progress $HOME/LINUX /media/$USER/$STICKNAME
fi
#
echo
echo "__________________________________________________________________________";
#
paplay $MUSIKDATEIORDNER/end.ogg
#
echo
echo "${FR}Ende der Sicherung auf USB-Stick $STICKNAME.${NO}"
echo "${FR}Der USB-Stick $STICKNAME wird anschließend ausgehängt!${NO}"
echo "${FR}Abschluss mit ENTER!${NO}"
read b
fi

# Zwischen date und + ist ein Leerzeichen zu setzen.
# Das Datums- und Uhrzeitformat ist in Hochkommata ” zu setzen. Der Befehl um date steht in STRG+` (Akutzeichen).
# Datei mit dem Präfix `datum_`, nachfolgendem Zeitstempel und der Extension .txt anlegen

touch /media/$USER/$STICKNAME/datum_`date +"%d-%m-%Y_%H-%M"`.txt

#
echo
echo "${FG}Unbedingt warten, bis der USB-Stick $STICKNAME ausgehangen worden ist!${NO}";
echo "Das ${FR}USB-Symbol${NO} in der Task-Leiste wird ausgeblendet!";
echo
umount /media/$USER/$STICKNAME
#
paplay $MUSIKDATEIORDNER/end.ogg
#
echo "Die Datensicherung war erfolgreich. Abschluss mit ENTER!"
read c
